@@ -11,8 +11,6 @@ class BulkMessage:
     identifier: bytes
     messages: List[KeiosMessage]
 
-class PoisonPill(BulkMessage):
-    pass
 
 class ZMQServer(ABC):
     """
